@@ -23,9 +23,11 @@ our @ISA = qw( Inline::C ); ## no critic (ISA)
 # Development releases will have a _0xx version suffix.
 # We eval the version number to accommodate dev. version numbering, as
 # described in perldoc perlmodstyle.
-our $VERSION = '0.38_002';
+our $VERSION = '0.38_003';
 $VERSION = eval $VERSION; ## no critic (eval)
 
+our $LOGFILE = q{c:/Users/daoswald/programming/repos/Inline-CPP/ilcpp.log};
+
 
 my $TYPEMAP_KIND;
 {
@@ -45,7 +47,7 @@ sub register {
         type     => 'compiled',
         suffix   => $Config{dlext},
     };
-}
+} ### Tested.
 
 #============================================================================
 # Validate the C++ config options: Now mostly done in Inline::C
@@ -54,17 +56,17 @@ sub validate {
     my ( $o, @config_options ) = @_;
     # DO NOT ALTER THE FOLLOWING TWO LINES: Makefile.PL locates them by
     # their comment text and alters them based on install inputs.
- $o->{ILSM}{MAKEFILE}{CC} ||= 'g++'; # default compiler
- $o->{ILSM}{MAKEFILE}{LIBS} ||= ['-lstdc++']; # default libs
+    $o->{ILSM}{MAKEFILE}{CC}   ||= 'g++ -xc++ '; # default compiler
+    $o->{ILSM}{MAKEFILE}{LIBS} ||= [' -lstdc++ ']; # default libs
 
     # I haven't traced it out yet, but $o->{STRUCT} gets set before getting
     # properly set from Inline::C's validate().
     $o->{STRUCT} ||= {
-              '.macros' => q{},
-              '.xs'     => q{},
-              '.any'    => 0,
-              '.all'    => 0,
-             };
+        '.macros' => q{},
+        '.xs'     => q{},
+        '.any'    => 0,
+        '.all'    => 0,
+    };
     $o->{ILSM}{AUTO_INCLUDE} ||= <<'END';
 #ifndef bool
 #include <%iostream%>
@@ -145,7 +147,7 @@ END_FLAVOR_DEFINITIONS
 
     # IT IS CRITICAL THAT THE FOLLOWING LINE NOT HAVE ITS "COMMENT"
     # ALTERED: Makefile.PL finds the line and alters the iostream name.
- my $iostream = 'iostream'; # default iostream filename
+    my $iostream = 'iostream'; # default iostream filename
 
     $o->{ILSM}{AUTO_INCLUDE} =~ s{%iostream%}{$iostream}xg;
 
@@ -445,12 +447,11 @@ sub wrap {
             }
             push @CODE, "\tRETVAL = " unless $void;
             push @CODE, call_or_instantiate(
-                $name,                          $ctor,
-                $dtor,                          $class,
-                $thing->{rconst},               $thing->{rtype},
+                $name, $ctor, $dtor, $class,
+                $thing->{rconst}, $thing->{rtype},
                 ( map { $_->{name} } @args ),   @tmp
             );
-            push @CODE, "\tbreak; /* case " . ($i+1) . " */\n";
+            push @CODE, "\tbreak; /* case " . ( $i + 1 ) . " */\n";
         }
         push @CODE, "default:\n";
         push @CODE, "\tRETVAL = " unless $void;
@@ -463,9 +464,7 @@ sub wrap {
     elsif ( $void ) {
         push @CODE, "\t";
         push @CODE, call_or_instantiate(
-            $name,              $ctor,
-            $dtor,              $class,
-            0,                  q{},
+            $name, $ctor, $dtor, $class, 0, q{},
             map { $_->{name} } @args
         );
     }
@@ -473,8 +472,7 @@ sub wrap {
         push @CODE, "\t";
         push @CODE, 'RETVAL = ';
         push @CODE, call_or_instantiate(
-            $name,              $ctor,
-            $dtor,              $class,
+            $name, $ctor, $dtor, $class,
             $thing->{rconst},   $thing->{rtype},
             map { $_->{name} } @args
         );
@@ -516,13 +514,13 @@ sub call_or_instantiate {
     $rval .= $name . '(' . join ( q{,}, @args ) . ')';
 
     return const_cast( $rval, $const, $type ) . ";\n";
-}
+} ### Tested.
 
 sub const_cast {
     my( $value, $const, $type ) = @_;
     return $value unless $const and $type =~ m/[*&]/x;
     return "const_cast<$type>($value)";
-}
+} ### Tested.
 
 sub write_typemap {
     my $o         = shift;
@@ -543,8 +541,6 @@ INPUT
 $TYPEMAP_KIND
 $o->{ILSM}{typeconv}{input_expr}{$TYPEMAP_KIND}
 END
-#    open TYPEMAP, "> $filename"
-#    print TYPEMAP <<END;
     open my $TYPEMAP_FH, '>', $filename
         or croak "Error: Can't write to $filename: $!";
     print {$TYPEMAP_FH} $tm_output;
@@ -635,6 +631,18 @@ END
     return join q{}, @enum;
 }
 
+#    my $log = "name: $name, ctor: $ctor, dtor: $dtor, class: $class, const: $const, type, $type, args: (@args)\n";
+#    $log .= "\t" . const_cast( $rval, $const, $type ) . ";\n";
+
+# log_this( $LOGFILE, $log );
+#sub log_this {
+#    my ( $filename, @output ) = @_;
+#    open my $fh, '>>', $filename or die $!;
+#    print {$fh} @output, "\n";
+#    close $fh or die $!;
+#}
+
+
 1;
 
 __END__
